@@ -32,10 +32,55 @@ def _percentile(a, q, interpolation='linear'):
     return np.percentile(a, q, interpolation=interpolation), n
 
 
-def percentile(a, q, interpolation='linear'):
+def _tdigest_chunk(a):
+
+    from crick import TDigest
+
+    t = TDigest()
+    t.update(a)
+
+    return t
+
+
+def _percentiles_from_tdigest(qs, digests):
+
+    from crick import TDigest
+
+    t = TDigest()
+    t.merge(*digests)
+
+    return np.array(t.quantile(qs / 100.0))
+
+
+def percentile(a, q, interpolation='linear', method='default'):
     """ Approximate percentile of 1-D array
 
-    See :func:`numpy.percentile` for more information
+    Parameters
+    ----------
+    a : Array
+    q : array_like of float
+        Percentile or sequence of percentiles to compute, which must be between
+        0 and 100 inclusive.
+    interpolation : {'linear', 'lower', 'higher', 'midpoint', 'nearest'}, optional
+        The interpolation method to use when the desired percentile lies
+        between two data points ``i < j``. Only valid for ``method='dask'``.
+
+        * 'linear': ``i + (j - i) * fraction``, where ``fraction``
+        is the fractional part of the index surrounded by ``i``
+        and ``j``.
+        * 'lower': ``i``.
+        * 'higher': ``j``.
+        * 'nearest': ``i`` or ``j``, whichever is nearest.
+        * 'midpoint': ``(i + j) / 2``.
+
+    method : {'default', 'dask', 'tdigest'}, optional
+        What method to use. By default will use dask's internal custom
+        algorithm (``'dask'``).  If set to ``'tdigest'`` will use tdigest for
+        floats and ints and fallback to the ``'dask'`` otherwise.
+
+    See Also
+    --------
+    numpy.percentile : Numpy's equivalent Percentile function
     """
     if not a.ndim == 1:
         raise NotImplementedError(
@@ -43,19 +88,49 @@ def percentile(a, q, interpolation='linear'):
     if isinstance(q, Number):
         q = [q]
     q = np.array(q)
-    token = tokenize(a, list(q), interpolation)
-    name = 'percentile_chunk-' + token
-    dsk = dict(((name, i), (_percentile, (key), q, interpolation))
-               for i, key in enumerate(a.__dask_keys__()))
-
-    name2 = 'percentile-' + token
-    dsk2 = {(name2, 0): (merge_percentiles, q, [q] * len(a.chunks[0]),
-                         sorted(dsk), interpolation)}
+    token = tokenize(a, q, interpolation)
 
     dtype = a.dtype
     if np.issubdtype(dtype, np.integer):
         dtype = (np.array([], dtype=dtype) / 0.5).dtype
 
+    allowed_methods = ['default', 'dask', 'tdigest']
+    if method not in allowed_methods:
+        raise ValueError("method can only be 'default', 'dask' or 'tdigest'")
+
+    if method == 'default':
+        internal_method = 'dask'
+    else:
+        internal_method = method
+
+    # Allow using t-digest if interpolation is allowed and dtype is of floating or integer type
+    if (internal_method == 'tdigest' and interpolation == 'linear' and
+            (np.issubdtype(dtype, np.floating) or np.issubdtype(dtype, np.integer))):
+
+        from dask.utils import import_required
+        import_required('crick',
+                        'crick is a required dependency for using the t-digest '
+                        'method.')
+
+        name = 'percentile_tdigest_chunk-' + token
+        dsk = dict(((name, i), (_tdigest_chunk, (key)))
+                   for i, key in enumerate(a.__dask_keys__()))
+
+        name2 = 'percentile_tdigest-' + token
+
+        dsk2 = {(name2, 0): (_percentiles_from_tdigest, q, sorted(dsk))}
+
+    # Otherwise use the custom percentile algorithm
+    else:
+
+        name = 'percentile_chunk-' + token
+        dsk = dict(((name, i), (_percentile, (key), q, interpolation))
+                   for i, key in enumerate(a.__dask_keys__()))
+
+        name2 = 'percentile-' + token
+        dsk2 = {(name2, 0): (merge_percentiles, q, [q] * len(a.chunks[0]),
+                             sorted(dsk), interpolation)}
+
     dsk = merge(dsk, dsk2)
     graph = HighLevelGraph.from_collections(name2, dsk, dependencies=[a])
     return Array(graph, name2, chunks=((len(q),),), dtype=dtype)
