@@ -291,3 +291,37 @@ def test_names():
 
     assert name.startswith('normal')
     assert len(key_split(name)) < 10
+
+
+def test_external_randomstate_class():
+    randomgen = pytest.importorskip('randomgen')
+
+    rs = da.random.RandomState(RandomState=lambda seed: randomgen.RandomGenerator(randomgen.DSFMT(seed)))
+    x = rs.normal(0, 1, size=(10), chunks=(5,))
+    assert_eq(x, x)
+
+    rs = da.random.RandomState(
+        RandomState=lambda seed: randomgen.RandomGenerator(randomgen.DSFMT(seed)),
+        seed=123
+    )
+    a = rs.normal(0, 1, size=(10), chunks=(5,))
+    rs = da.random.RandomState(
+        RandomState=lambda seed: randomgen.RandomGenerator(randomgen.DSFMT(seed)),
+        seed=123
+    )
+    b = rs.normal(0, 1, size=(10), chunks=(5,))
+    assert a.name == b.name
+    assert_eq(a, b)
+
+
+def test_auto_chunks():
+    with dask.config.set({'array.chunk-size': '50 MiB'}):
+        x = da.random.random((10000, 10000))
+        assert 4 < x.npartitions < 32
+
+
+def test_randint_dtype():
+    x = da.random.randint(0, 255, size=10, dtype='uint8')
+    assert_eq(x, x)
+    assert x.dtype == 'uint8'
+    assert x.compute().dtype == 'uint8'
