@@ -1,5 +1,4 @@
 import random
-from distutils.version import LooseVersion
 
 import numpy as np
 import pytest
@@ -15,10 +14,6 @@ if sparse:
     pytest.importorskip("numba", minversion="0.40.0")
 
 
-if LooseVersion(np.__version__) < '1.11.2':
-    pytestmark = pytest.mark.skip
-
-
 functions = [
     lambda x: x,
     lambda x: da.expm1(x),
