@@ -5,8 +5,8 @@ from operator import add, neg
 import sys
 import pytest
 
-optimize2 = (sys.flags.optimize == 2)
-if not optimize2:
+
+if sys.flags.optimize != 2:
     pytest.importorskip("graphviz")
     from dask.dot import dot_graph, task_label, label, to_graphviz
 else:
@@ -15,7 +15,16 @@ else:
 
 from dask import delayed
 from dask.utils import ensure_not_exists
-from IPython.display import Image, SVG
+try:
+    from IPython.display import Image, SVG
+except ImportError:
+    ipython_not_installed = True
+    Image = None
+    SVG = None
+else:
+    ipython_not_installed = False
+ipython_not_installed_mark = pytest.mark.skipif(ipython_not_installed,
+                                                reason='IPython not installed')
 
 
 # Since graphviz doesn't store a graph, we need to parse the output
@@ -108,11 +117,11 @@ def test_aliases():
 
 
 @pytest.mark.parametrize('format,typ', [
-    ('png', Image),
+    pytest.param('png', Image, marks=ipython_not_installed_mark),
     pytest.param('jpeg', Image, marks=pytest.mark.xfail(reason='jpeg not always supported in dot')),
     ('dot', type(None)),
     ('pdf', type(None)),
-    ('svg', SVG),
+    pytest.param('svg', SVG, marks=ipython_not_installed_mark),
 ])
 def test_dot_graph(tmpdir, format, typ):
     # Use a name that the shell would interpret specially to ensure that we're
@@ -132,11 +141,11 @@ def test_dot_graph(tmpdir, format, typ):
 
 
 @pytest.mark.parametrize('format,typ', [
-    ('png', Image),
+    pytest.param('png', Image, marks=ipython_not_installed_mark),
     pytest.param('jpeg', Image, marks=pytest.mark.xfail(reason='jpeg not always supported in dot')),
     ('dot', type(None)),
     ('pdf', type(None)),
-    ('svg', SVG),
+    pytest.param('svg', SVG, marks=ipython_not_installed_mark),
 ])
 def test_dot_graph_no_filename(tmpdir, format, typ):
     before = tmpdir.listdir()
@@ -147,6 +156,7 @@ def test_dot_graph_no_filename(tmpdir, format, typ):
     assert isinstance(result, typ)
 
 
+@ipython_not_installed_mark
 def test_dot_graph_defaults():
     # Test with default args.
     default_name = 'mydask'
@@ -162,26 +172,18 @@ def test_dot_graph_defaults():
         ensure_not_exists(target)
 
 
-def test_filenames_and_formats():
-    # Test with a variety of user provided args
-    filenames = ['mydaskpdf', 'mydask.pdf', 'mydask.pdf', 'mydaskpdf', 'mydask.pdf.svg']
-    formats = ['svg', None, 'svg', None, None]
-    targets = ['mydaskpdf.svg', 'mydask.pdf', 'mydask.pdf.svg', 'mydaskpdf.png', 'mydask.pdf.svg']
-
-    result_types = {
-        'png': Image,
-        'jpeg': Image,
-        'dot': type(None),
-        'pdf': type(None),
-        'svg': SVG,
-    }
-
-    for filename, format, target in zip(filenames, formats, targets):
-        expected_result_type = result_types[target.split('.')[-1]]
-        result = dot_graph(dsk, filename=filename, format=format)
-        assert os.path.isfile(target)
-        assert isinstance(result, expected_result_type)
-        ensure_not_exists(target)
+@pytest.mark.parametrize('filename,format,target,expected_result_type', [
+    pytest.param('mydaskpdf', 'svg', 'mydaskpdf.svg', SVG, marks=ipython_not_installed_mark),
+    ('mydask.pdf', None, 'mydask.pdf', type(None)),
+    pytest.param('mydask.pdf', 'svg', 'mydask.pdf.svg', SVG, marks=ipython_not_installed_mark),
+    pytest.param('mydaskpdf', None, 'mydaskpdf.png', Image, marks=ipython_not_installed_mark),
+    pytest.param('mydask.pdf.svg', None, 'mydask.pdf.svg', SVG, marks=ipython_not_installed_mark),
+])
+def test_filenames_and_formats(filename, format, target, expected_result_type):
+    result = dot_graph(dsk, filename=filename, format=format)
+    assert os.path.isfile(target)
+    assert isinstance(result, expected_result_type)
+    ensure_not_exists(target)
 
 
 def test_delayed_kwargs_apply():
